@@ -6,17 +6,16 @@ The base WSGI application definition.
 Applications which use the WebCore framework plug into this base application.
 """
 
-import sys, os, pkg_resources, types
+import types
 
 import paste
 from webob import Request, Response
 
 import web, web.core, web.utils
-from web.core import Controller, middleware
+from web.core import middleware
 from web.core.dialects import Dialect
 
 from web.utils.object import get_dotted_object
-from paste.deploy.converters import asbool, asint, aslist
 
 
 __all__ = ['Application']
@@ -42,7 +41,7 @@ class Application(object):
         
         web.core.config.update(config)
         
-        if not isinstance(self.root, Dialect) and not callable(self.root):
+        if not isinstance(self.root, Dialect) and not hasattr(self.root, '__call__'):
             raise TypeError('Root controller must be dialect subclass or executable.')
         
         if not isinstance(self.root, Dialect):
@@ -114,7 +113,7 @@ class Application(object):
         if isinstance(root, type):
             root = root()
         
-        if not isinstance(root, Dialect) and not callable(root):
+        if not isinstance(root, Dialect) and not hasattr(root, '__call__'):
             raise ValueError("The root controller must be defined using package dot-colon-notation or direct reference and must be either a WSGI app or Dialect.")
         
         config['web.root'] = root
